@@ -5,9 +5,9 @@
 # Author          : Ulrich Pfeifer
 # Created On      : Thu Feb  1 16:08:41 1996
 # Last Modified By: Ulrich Pfeifer
-# Last Modified On: Tue Feb  6 17:25:32 1996
+# Last Modified On: Mon May  6 15:18:48 1996
 # Language        : Perl
-# Update Count    : 3
+# Update Count    : 7
 # Status          : Unknown, Use with caution!
 # 
 # (C) Copyright 1996, Universitt Dortmund, all rights reserved.
@@ -23,7 +23,7 @@ package Text::German::Util;
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(bit_to_int wordclass $CAPITAL $LOWER $ADJEKTIV $UMLAUTR 
-	     $VERB $FUNNY $ADJEKTIV);
+	     $VERB $FUNNY $ADJEKTIV $ANY);
 
 sub bit_to_int {
     my $bitvec = shift;
@@ -31,17 +31,22 @@ sub bit_to_int {
     unpack('I', pack('b*', $bitvec)."\0\0\0\0");
 }
 
-$CAPITAL  = bit_to_int('01000');
+$CAPITAL  = bit_to_int('10000');
 $LOWER    = bit_to_int('01111');
 $ADJEKTIV = bit_to_int('00100');
 $VERB     = bit_to_int('01000');
 $FUNNY    = bit_to_int('01001');
-
+$ANY      = bit_to_int('11111');
 $UMLAUTR  = "[]";
+
 sub wordclass {
-    if ($_[0] =~ /^[A-Z]/) {
-        $CAPITAL;
-    } else {
-        $LOWER;
-    }
+  my ($word, $satz_anfang) = @_;
+  
+  if ($satz_anfang) {
+    return $ANY;
+  } elsif ($word =~ /^[A-Z]/) {
+    $CAPITAL;
+  } else {
+    $LOWER;
+  }
 }
